@@ -10,6 +10,7 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 'use strict';
+import { CheNotification } from '../../../../components/notification/che-notification.factory';
 import {TeamDetailsService} from '../team-details.service';
 /**
  * @ngdoc controller
@@ -41,7 +42,7 @@ export class ListTeamWorkspacesController {
   /**
    * Service for displaying notifications.
    */
-  private cheNotification: any;
+  private cheNotification: CheNotification;
   /**
    * Service for displaying dialogs.
    */
@@ -242,9 +243,9 @@ export class ListTeamWorkspacesController {
           this.cheNotification.showError('Delete failed.');
         } else {
           if (numberToDelete === 1) {
-            this.cheNotification.showInfo(workspaceName + ' has been removed.');
+            this.cheNotification.showSuccess(workspaceName + ' has been removed.');
           } else {
-            this.cheNotification.showInfo('Selected workspaces have been removed.');
+            this.cheNotification.showSuccess('Selected workspaces have been removed.');
           }
         }
       });
